aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorGravatar Arun Prakash Jana <engineerarun@gmail.com>2020-07-07 07:57:43 +0530
committerGravatar Arun Prakash Jana <engineerarun@gmail.com>2020-07-07 07:57:43 +0530
commitd3e20e90159fb1d6064d4b7c4147aca290ba0f20 (patch)
tree7fd5c8a57eb44a05c8e404b4355ae83675fa76eb /src
parent6fa4978230becc487521c600cfc5ff3f132fb8d6 (diff)
downloadnnn-d3e20e90159fb1d6064d4b7c4147aca290ba0f20.tar.gz
Use the term mark instead of pin
Diffstat (limited to 'src')
-rw-r--r--src/nnn.c16
-rw-r--r--src/nnn.h4
2 files changed, 10 insertions, 10 deletions
diff --git a/src/nnn.h b/src/nnn.h
index 1f7f664..57c8649 100644
--- a/src/nnn.h
+++ b/src/nnn.h
@@ -66,7 +66,7 @@ enum action {
SEL_CTX7,
SEL_CTX8,
#endif
- SEL_PIN,
+ SEL_MARK,
SEL_FLTR,
SEL_MFLTR,
SEL_HIDDEN,
@@ -181,7 +181,7 @@ static struct key bindings[] = {
{ '8', SEL_CTX8 },
#endif
/* Mark a path to visit later */
- { ',', SEL_PIN },
+ { ',', SEL_MARK },
/* Filter */
{ '/', SEL_FLTR },
/* Toggle filter mode */
diff --git a/src/nnn.c b/src/nnn.c
index 45dc18c..e23a5a8 100644
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -2651,7 +2651,7 @@ static int filterentries(char *path, char *lastname)
switch (*ch) {
case '\'': // fallthrough /* Go to first non-dir file */
case '+': // fallthrough /* Toggle auto-advance */
- case ',': // fallthrough /* Pin CWD */
+ case ',': // fallthrough /* Mark CWD */
case '-': // fallthrough /* Visit last visited dir */
case '.': // fallthrough /* Show hidden files */
case ';': // fallthrough /* Run plugin key */
@@ -4133,7 +4133,7 @@ static size_t handle_bookmark(const char *bmark, char *newpath)
int fd;
size_t r = xstrsncpy(g_buf, messages[MSG_BOOKMARK_KEYS], CMD_LEN_MAX);
- if (bmark) { /* There is a pinned directory */
+ if (bmark) { /* There is a marked directory */
g_buf[--r] = ' ';
g_buf[++r] = ',';
g_buf[++r] = '\0';
@@ -4144,7 +4144,7 @@ static size_t handle_bookmark(const char *bmark, char *newpath)
r = FALSE;
fd = get_input(NULL);
- if (fd == ',') /* Visit pinned directory */
+ if (fd == ',') /* Visit marked directory */
bmark ? xstrsncpy(newpath, bmark, PATH_MAX) : (r = MSG_NOT_SET);
else if (!get_kv_val(bookmark, newpath, fd, maxbm, NNN_BMS))
r = MSG_INVALID_KEY;
@@ -4177,7 +4177,7 @@ static void show_help(const char *path)
"5Ret Rt l Open%-20c' First file/match\n"
"9g ^A Top%-21c. Toggle hidden\n"
"9G ^E End%-21c+ Toggle auto-advance\n"
- "9b ^/ Bookmark key%-12c, Pin CWD\n"
+ "9b ^/ Bookmark key%-12c, Mark CWD\n"
"a1-4 Context 1-4%-7c(Sh)Tab Cycle context\n"
"aEsc Send to FIFO%-11c^L Redraw\n"
"c? Help, conf%-13c^G QuitCD\n"
@@ -5666,7 +5666,7 @@ nochange:
goto nochange;
}
/* Pin current directory */
free(mark);
mark = xstrdup(path);
@@ -5749,7 +5749,7 @@ nochange:
goto nochange;
}
/* Pin current directory */
free(mark);
mark = xstrdup(path);
@@ -5833,7 +5833,7 @@ nochange:
goto nochange;
}
/* Pin current directory */
free(mark);
mark = xstrdup(path);
@@ -5870,7 +5870,7 @@ nochange:
watch = TRUE;
goto begin;
- case SEL_PIN:
+ case SEL_MARK:
free(mark);
mark = xstrdup(path);
printwait(mark, &presel);
@@ -5666,7 +5666,7 @@ nochange:
goto nochange;
}
- /* Pin current directory */
+ /* Mark current directory */
free(mark);
mark = xstrdup(path);
@@ -5749,7 +5749,7 @@ nochange:
goto nochange;
}
- /* Pin current directory */
+ /* Mark current directory */
free(mark);
mark = xstrdup(path);
@@ -5833,7 +5833,7 @@ nochange:
goto nochange;
}
- /* Pin current directory */
+ /* Mark current directory */
free(mark);
mark = xstrdup(path);